macro_rules! decl_bridge_messages_runtime_apis {
    ($chain: ident) => { ... };
}
Convenience macro that declares bridge messages runtime apis and related constants for a chain. This includes:

  • chain-specific bridge runtime APIs:
    • To<ThisChain>OutboundLaneApi
    • From<ThisChain>InboundLaneApi
  • constants that are stringified names of runtime API methods:
    • FROM_<THIS_CHAIN>_MESSAGE_DETAILS_METHOD, The name of the chain has to be specified in snake case (e.g. bridge_hub_polkadot).