WeightExtraOps

Trait WeightExtraOps 

pub trait WeightExtraOps {
    // Required method
    fn min_components_checked_div(&self, other: Weight) -> Option<u64>;
}
All extra operations with weights that we need in bridges.

Required Methods

fn min_components_checked_div(&self, other: Weight) -> Option<u64>

Checked division of individual components of two weights.

Divides components and returns minimal division result. Returns None if one of other weight components is zero.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl WeightExtraOps for Weight

Implementors